interface RTCHelperOptions {
    /**
     * The URL of the signalling server.
     * @example "wss://example.com:8080"
     */
    signallingServerUrl: string;
    /**
     * The ID of the peer.
     * If not set, will be generated using `nanoid(6)`.
     * @default nanoid(6)
     */
    id?: string;
    /**
     * Whether to print debug information.
     * @default false
     */
    debug?: boolean;
}
declare class RTCHelper {
    #private;
    constructor(options: RTCHelperOptions);
    addMessage(message: MessageEvent): void;
    /**
     * You should call this function to connection other peers.
     * @returns The ID of the peer. You need **hold** this ID to do next operations.
     */
    registerRemote(remoteId?: string): Promise<string>;
    broadcast<T>(message: T): void;
    onBroadcast<T>(callback: (message: MessageEvent<T>) => void): void;
}

export { RTCHelper, type RTCHelperOptions };
